#![allow(non_upper_case_globals)]
#![allow(non_camel_case_types)]
#![allow(non_snake_case)]


use std::ffi::CString;
use std::os::raw::c_char;
use std::os::raw::c_int;

/*
 * Pull our wacky rsyslog.h generated bindings
 */
include!(concat!(env!("OUT_DIR"), "/bindings.rs"));

/**
 * Set the type of rsyslog module, in this case an input module
 */
#[no_mangle]
pub extern fn modGetType(m: &mut eModType_t) -> rsRetVal {
    // Set ourselves up as an input module
    *m = 0;
    return 0; // ok
}

/**
 * Set the rsyslog module name
 */
#[no_mangle]
pub extern fn modGetCnfName(name: *mut *const c_char) -> rsRetVal {
    let n: CString = CString::new("impstatsd").expect("Failed to alloc CString");
    /*
     * This is awful, and I hate C
     */
    unsafe {
        *name = n.as_ptr();
    }
    return 0; // ok
}


#[no_mangle]
pub extern fn modInit(versionRequested: c_int,
    versionProvided: *mut c_int,
    queryEntryFunc: *mut Option<unsafe extern "C" fn() -> rsRetVal>,
    hostEntryFunc: *mut Option<unsafe extern "C" fn() -> rsRetVal>,
    modInfo: modInfo_t) -> rsRetVal {

    println!(">> Bootstrapping Rust module");

    let mut iret = rsRetVal__RS_RET_OK;

    println!(">> Finished bootstrapping Rust module");
    return iret;
}


#[no_mangle]
pub extern fn modExit() -> rsRetVal {
    println!(">> Exiting Rust module");
    rsRetVal__RS_RET_OK
}



#[cfg(test)]
mod tests {
    use super::*;

    /**
     * Verify that the modGetType function works properly
     */
    #[test]
    fn test_modGetType() {
        /*
         * Setting this to some garbage value
         */
        let mut m: eModType_t = 2;
        assert_eq!(0, modGetType(&mut m));
        assert_eq!(0, m);
    }
}
